Tla�tko vloit tabulku

Tlačítko vložiť tabuľku | Obsah

Tlačítko vložiť tabuľku otvorý následujúce okno, vňom môžete definovať novú tabuľku.
Popis položiek:

Stĺpce | Počet stĺpcov v tabuľke.
Riadky | Počet riadkov v tabuľke.
Vnútorný okraj bunky | Vnútorný okraj bunky.
Vnútorný okraj tabuľky� | Vnútorný okraj tabuľky.
Zarovnanie | Zarovnať tabuľky.
Riadok | Hrúbka riadku tabuľky.
Šírka | Šírka tabuľky v pixelech.
Výškaka | Výška tabuľky v pixelech.

Choď na: Obsah | Nahor